@@ -9,9 +9,6 @@ class SGraph:
         self.p = None
         self.pi = None
 
-    def __copy__(self):  # todo don't work
-        return SGraph(self.gr.copy())
-
     def clean_copy(self):
         G = self.gr.__class__()
         G.add_edges_from(self.gr.edges())
@@ -36,6 +33,10 @@ class SGraph:
         else:
             return self.gr.nodes()
 
+    def get_nodes_with(self, attr, value):
+        ids = self.get_ids(stable=True)
+        return ids[self.get_attributes(attr) == value]
+
     def get_edges(self, stable=False):
         if stable:
             return np.array(list(self.gr.edges(data=False)))
@@ -139,8 +140,11 @@ class SGraph:
     def add_edges(self, edges):
         self.gr.add_edges_from(edges)
 
-    def get_edge_data(self, u, v, frm):
-        return self.gr[u][v][frm]
+    def get_edge_data(self, u, v, frm, bsc=0):
+        try:
+            return self.gr[u][v][frm]
+        except:
+            return bsc
 
     def set_edge_data(self, u, v, to, value):
         self.gr[u][v][to] = value
@@ -157,72 +161,53 @@ class SGraph:
     def size(self):
         return self.gr.number_of_nodes()
 
-    def count_in_degree(self, ind, w=None, inn=None):
-        res = self.get_in_degrees(ind, w=w)
-        if inn is None:
-            return res.size
-        else:
-            return res[np.isin(res, inn)].size
+    def size_edge(self):
+        return self.gr.number_of_edges()
 
-    def count_out_degree(self, out, w=None, inn=None):
-        res = self.get_out_degrees(out, w=w)
-        if inn is None:
-            return res.size
-        else:
-            return res[np.isin(res, inn)].size
+    def count_in_degree(self, ind, w=None):
+        if w is None:
+            return self.get_in_degrees(ind).size
+        res = self.get_in_degrees(ind, w=w, bsc=1)
+        return np.sum(res)
+
+    def count_out_degree(self, out, w=None,):
+        if w is None:
+            return self.get_out_degrees(out).size
+        res = self.get_out_degrees(out, w=w, bsc=1)
+        return np.sum(res)
 
     def get_count_edges(self):
         return self.gr.number_of_edges()
 
-    def get_in_degrees(self, ind, un=True, w=None):
+    def get_in_degrees(self, ind, w=None, un=True, bsc=0):
         if self.directed():
-            try:
-                res = [
-                    x[0]
-                    for x in self.gr.in_edges(ind)
-                    if self.get_edge_data(x[0], x[1], w) > 0
-                ]
-            except:
-                res = [x[0] for x in self.gr.in_edges(ind)]
-
-            if un:
-                return np.unique(res)
-            else:
-                return np.array(res)
+            res = [x[0] for x in self.gr.in_edges(ind)]
         else:
             res = [x[0] for x in self.gr.edges(ind) if x[0] != ind] + [
                 x[1] for x in self.gr.edges(ind) if x[1] != ind
             ]
 
-            if un:
-                return np.unique(res)
-            else:
-                return np.array(res)
+        if un:
+            res = np.unique(res)
+        if w is None:
+            return np.array(res)
+        else:
+            return np.array([self.get_edge_data(res, ind, w, bsc=bsc)])
 
-    def get_out_degrees(self, out, un=True, w=None):
+    def get_out_degrees(self, out, w=None, un=True, bsc=0):
         if self.directed():
-            try:
-                res = [
-                    x[1]
-                    for x in self.gr.out_edges(out)
-                    if self.get_edge_data(x[0], x[1], w) > 0
-                ]
-            except:
-                res = [x[1] for x in self.gr.out_edges(out)]
-
-            if un:
-                return np.unique(res)
-            else:
-                return np.array(res)
+            res = [x[1] for x in self.gr.out_edges(out)]
         else:
             res = [x[0] for x in self.gr.edges(out) if x[0] != out] + [
                 x[1] for x in self.gr.edges(out) if x[1] != out
             ]
 
-            if un:
-                return np.unique(res)
-            else:
-                return np.array(res)
+        if un:
+            res = np.unique(res)
+        if w is None:
+            return np.array(res)
+        else:
+            return np.array([self.get_edge_data(out, res, w, bsc=bsc)])
 
     def get_data(self, attrs=None, nodes=None):
         if nodes is None:
