@@ -1,21 +1,22 @@
 import numpy as np
 import networkx as nx
 
+from scipy.stats import powerlaw
+
 from pge.init.classes.graph import SGraph
 from pge.init.add import actual
 
-from scipy.stats import powerlaw
 
 class Creator:
     @staticmethod
-    def make_tbt(nm, alpha, beta, sigma, min_r=(1, 1)):
-        ind_d = []  # np.around(pwrlaw(alpha, nm, min_r[0], 1))
-        out_d = []  # np.around(pwrlaw(beta, nm, min_r[1], 1))
+    def tbt(nm, alpha, beta):
+        ind_d = np.around(1/powerlaw.rvs(alpha, size=nm))
+        out_d = np.around(1/powerlaw.rvs(beta, size=nm))
 
         zv = np.sum(np.subtract(ind_d, out_d))
         k = 1 - min([0.5, 1 - alpha ** -1, 1 - beta ** -1]) / 2
         while np.abs(zv) > nm ** k:
-            i_s = np.random.choice(np.arange(nm), int(np.abs(zv)), replace=False)
+            i_s = np.random.choice(nm, min(int(np.abs(zv)), nm), replace=False)
 
             for i in i_s:
                 if zv < 0:
@@ -37,21 +38,8 @@ class Creator:
                 if out_d[int(j)] > gr.count_out_degree(j):
                     gr.add_edge(j, i)
 
-        actual(gr, sigma)
         return gr
 
-    @staticmethod
-    def create_subgraph(g, start_node, sz):
-        un = np.array([start_node])
-        nxt = np.copy(un)
-
-        while sz >= un.size:
-            print(un.size)
-            nxt = np.append(g.get_in_degrees(nxt), g.get_out_degrees(nxt))
-            un = np.unique(np.append(un, nxt))
-        res = g.subgraph(un[:sz])
-        return SGraph(res)
-
     @staticmethod
     def make_from_data(network, pre="../", nm=None, sigma=None):
         path = pre + "pge/samples/networks/web-"
