@@ -12,20 +12,18 @@ def estimate_rank(graph, tp, pers="tel", c=0.85, max_iter=100, eps=0.000001, w=N
     graph.set_attrs(tp, res)
 
 
-def esp(graph, tp, c=0.85, w=None):
+def esp(graph, tp, frm, per="tel", c=0.85, w=None):
     nodes = graph.get_ids()
     graph.set_attrs(tp, 0)
 
     for node in nodes:
-        rank = (1 - c) * graph.get_attr(node, "tel")
+        rank = (1 - c) * graph.get_attr(node, per)
         k = graph.get_in_degrees(node, w=w)
 
         for n in k:
-            t = graph.get_attr(n, "out")
-            if t == 0:
-                t = 0
-            else:
-                t = c * graph.get_attr(n, "one") / t
+            t = graph.count_out_degree(n)
+            if t != 0:
+                t = c * graph.get_attr(n, frm) / t
 
             if tp == "max":
                 rank = max(rank, t)
